pub struct Issue {
pub path: PathBuf,
pub line_num: usize,
pub byte_offset: usize,
pub typo: String,
pub corrections: Vec<String>,
}Fields
path: PathBufline_num: usizebyte_offset: usizetypo: Stringcorrections: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Issue
impl<'de> Deserialize<'de> for Issue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Issue for Issue
impl Issue for Issue
Sourcefn analyzer_id(&self) -> String
fn analyzer_id(&self) -> String
Name of the analyzer which produce the issue
Sourcefn fingerprint(&self) -> Digest
fn fingerprint(&self) -> Digest
Fingerprint is used to track an issue over evolutions of the code.
Ideally, even if the line changed but the issue is the same, the
fingerprint should not change.
Sourcefn severity(&self) -> Severity
fn severity(&self) -> Severity
Severity of the reported issue, can be used to prioritize the issues
to fix.
Sourcefn location(&self) -> Option<Location>
fn location(&self) -> Option<Location>
Location of the issue in a file. This information is crucial for nice
display in UI.
Sourcefn issue_uid(&self) -> String
fn issue_uid(&self) -> String
Unique identifier of the issue. Default implementation concatenate
analyzer_id() and issue_id().Sourcefn other_locations(&self) -> Vec<Location>
fn other_locations(&self) -> Vec<Location>
Optional other locations related to the same issue.